# -*- coding: utf-8 -*-
"""typing_extensions exports"""
from typing_extensions import (
    TYPE_CHECKING,
    Annotated,
    AsyncContextManager,
    AsyncGenerator,
    AsyncIterable,
    AsyncIterator,
    Awaitable,
    ChainMap,
    ClassVar,
    Concatenate,
    ContextManager,
    Coroutine,
    Counter,
    DefaultDict,
    Deque,
    Final,
    IntVar,
    Literal,
    NewType,
    NoReturn,
    OrderedDict,
    ParamSpec,
    ParamSpecArgs,
    ParamSpecKwargs,
    Protocol,
    SupportsIndex,
    Text,
    Type,
    TypeAlias,
    TypedDict,
    TypeGuard,
    final,
    get_args,
    get_origin,
    get_type_hints,
    overload,
    runtime,
    runtime_checkable,
)

__all__ = (
    'Annotated',
    'AsyncContextManager',
    'AsyncGenerator',
    'AsyncIterable',
    'AsyncIterator',
    'Awaitable',
    'ChainMap',
    'ClassVar',
    'Concatenate',
    'ContextManager',
    'Coroutine',
    'Counter',
    'DefaultDict',
    'Deque',
    'Final',
    'IntVar',
    'Literal',
    'NewType',
    'NoReturn',
    'OrderedDict',
    'ParamSpec',
    'ParamSpecArgs',
    'ParamSpecKwargs',
    'Protocol',
    'SupportsIndex',
    'TYPE_CHECKING',
    'Text',
    'Type',
    'TypeAlias',
    'TypeGuard',
    'TypedDict',
    '__all_typing_extensions__',
    'final',
    'get_args',
    'get_origin',
    'get_type_hints',
    'overload',
    'runtime',
    'runtime_checkable',
)
__all_typing_extensions__ = __all__



# -*- coding: utf-8 -*-
"""typing exports"""
from typing import (
    IO,
    TYPE_CHECKING,
    AbstractSet,
    Any,
    AnyStr,
    AsyncContextManager,
    AsyncGenerator,
    AsyncIterable,
    AsyncIterator,
    Awaitable,
    ByteString,
    Callable,
    ChainMap,
    ClassVar,
    Collection,
    Container,
    ContextManager,
    Coroutine,
    Counter,
    DefaultDict,
    Deque,
    Dict,
    FrozenSet,
    Generator,
    Generic,
    Hashable,
    ItemsView,
    Iterable,
    Iterator,
    KeysView,
    List,
    Mapping,
    MappingView,
    MutableMapping,
    MutableSequence,
    MutableSet,
    NamedTuple,
    NewType,
    Optional,
    Reversible,
    Sequence,
    Set,
    Sized,
    SupportsAbs,
    SupportsBytes,
    SupportsComplex,
    SupportsFloat,
    SupportsInt,
    SupportsRound,
    Text,
    Tuple,
    Type,
    TypeVar,
    Union,
    ValuesView,
    cast,
    get_type_hints,
    no_type_check,
    no_type_check_decorator,
    overload,
)

__all__ = (
    'AbstractSet',
    'Any',
    'AnyStr',
    'AsyncContextManager',
    'AsyncGenerator',
    'AsyncIterable',
    'AsyncIterator',
    'Awaitable',
    'ByteString',
    'Callable',
    'ChainMap',
    'ClassVar',
    'Collection',
    'Container',
    'ContextManager',
    'Coroutine',
    'Counter',
    'DefaultDict',
    'Deque',
    'Dict',
    'FrozenSet',
    'Generator',
    'Generic',
    'Hashable',
    'IO',
    'ItemsView',
    'Iterable',
    'Iterator',
    'KeysView',
    'List',
    'Mapping',
    'MappingView',
    'MutableMapping',
    'MutableSequence',
    'MutableSet',
    'NamedTuple',
    'NewType',
    'Optional',
    'Reversible',
    'Sequence',
    'Set',
    'Sized',
    'SupportsAbs',
    'SupportsBytes',
    'SupportsComplex',
    'SupportsFloat',
    'SupportsInt',
    'SupportsRound',
    'TYPE_CHECKING',
    'Text',
    'Tuple',
    'Type',
    'TypeVar',
    'Union',
    'ValuesView',
    '__all_typing__',
    'cast',
    'get_type_hints',
    'no_type_check',
    'no_type_check_decorator',
    'overload',
)
__all_typing__ = __all__



# -*- coding: utf-8 -*-
"""typing + typing_extensions + misc types/aliases"""
import typing

import typing_extensions

from xtyping._meta import __version__
from xtyping._typing import (
    IO,
    TYPE_CHECKING,
    AbstractSet,
    Any,
    AnyStr,
    AsyncContextManager,
    AsyncGenerator,
    AsyncIterable,
    AsyncIterator,
    Awaitable,
    ByteString,
    Callable,
    ChainMap,
    ClassVar,
    Collection,
    Container,
    ContextManager,
    Coroutine,
    Counter,
    DefaultDict,
    Deque,
    Dict,
    FrozenSet,
    Generator,
    Generic,
    Hashable,
    ItemsView,
    Iterable,
    Iterator,
    KeysView,
    List,
    Mapping,
    MappingView,
    MutableMapping,
    MutableSequence,
    MutableSet,
    NamedTuple,
    NewType,
    Optional,
    Reversible,
    Sequence,
    Set,
    Sized,
    SupportsAbs,
    SupportsBytes,
    SupportsComplex,
    SupportsFloat,
    SupportsInt,
    SupportsRound,
    Text,
    Tuple,
    Type,
    TypeVar,
    Union,
    ValuesView,
    __all_typing__,
    cast,
    get_type_hints,
    no_type_check,
    no_type_check_decorator,
    overload,
)
from xtyping._typing_extensions import (
    TYPE_CHECKING,
    Annotated,
    AsyncContextManager,
    AsyncGenerator,
    AsyncIterable,
    AsyncIterator,
    Awaitable,
    ChainMap,
    ClassVar,
    Concatenate,
    ContextManager,
    Coroutine,
    Counter,
    DefaultDict,
    Deque,
    Final,
    IntVar,
    Literal,
    NewType,
    NoReturn,
    OrderedDict,
    ParamSpec,
    ParamSpecArgs,
    ParamSpecKwargs,
    Protocol,
    SupportsIndex,
    Text,
    Type,
    TypeAlias,
    TypedDict,
    TypeGuard,
    __all_typing_extensions__,
    final,
    get_args,
    get_origin,
    get_type_hints,
    overload,
    runtime,
    runtime_checkable,
)
from xtyping.shed import (
    _DT,
    _R,
    _RT,
    _T,
    AF,
    DT,
    FALSE,
    FN,
    KT,
    RT,
    STDIN,
    STDIO,
    TRUE,
    VT,
    AnyCallable,
    AnyFunction,
    AnyIterable,
    AnyIterator,
    ArrayShape,
    ArrShape,
    Bytes,
    CmdArgsType,
    DictAny,
    DictAnyAny,
    DictFloat,
    DictFloatFloat,
    DictInt,
    DictIntInt,
    DictNumber,
    DictNumberNumber,
    DictStr,
    DictStrAny,
    DictStrInt,
    DictStrStr,
    El,
    Element,
    EnvMap,
    EnvType,
    F,
    Flint,
    FsPath,
    FsPathLike,
    FuncType,
    HrTime,
    IntStr,
    IterableAny,
    IterableFloat,
    IterableInt,
    IterableNumber,
    IterableStr,
    IterableT,
    JsonArrT,
    JsonDictT,
    JsonListT,
    JsonObjT,
    KeyT,
    KeyType,
    ListAny,
    ListFloat,
    ListInt,
    ListListStr,
    ListNumber,
    ListStr,
    ListT,
    N,
    NoneBytes,
    NoneStr,
    NoneStrBytes,
    NoneType,
    Null,
    Number,
    OptFloat,
    OptInt,
    OptionalFloat,
    OptionalInt,
    OptionalStr,
    OptStr,
    Path,
    PathLike,
    R,
    ReturnT,
    ReturnType,
    SetAny,
    SetFloat,
    SetInt,
    SetNumber,
    SetStr,
    SetT,
    ShapeType,
    StrBytes,
    StrEnum,
    StringEnum,
    StrIntFloat,
    T,
    T_co,
    T_contra,
    TupleStrs,
    TupleStrStr,
    Txt,
    V_co,
    ValT,
    ValType,
    VT_co,
    __all_shed__,
    null,
)

#
# __all__ = (
#     'TRUE',
#     'FALSE',
#     'AF',
#     'AbstractSet',
#     'Any',
#     'AnyCallable',
#     'AnyFunction',
#     'AnyIterable',
#     'AnyIterator',
#     'AnyStr',
#     'ArrShape',
#     'ArrayShape',
#     'AsyncContextManager',
#     'AsyncGenerator',
#     'AsyncIterable',
#     'AsyncIterator',
#     'Awaitable',
#     'ByteString',
#     'Bytes',
#     'Callable',
#     'ChainMap',
#     'ClassVar',
#     'CmdArgsType',
#     'Collection',
#     'Container',
#     'ContextManager',
#     'Coroutine',
#     'Counter',
#     'DT',
#     'DefaultDict',
#     'Deque',
#     'Dict',
#     'DictAny',
#     'DictAnyAny',
#     'DictFloat',
#     'DictFloatFloat',
#     'DictInt',
#     'DictIntInt',
#     'DictNumber',
#     'DictNumberNumber',
#     'DictStr',
#     'DictStrAny',
#     'DictStrInt',
#     'DictStrStr',
#     'El',
#     'Element',
#     'EnvMap',
#     'EnvType',
#     'F',
#     'FN',
#     'Final',
#     'Flint',
#     'FrozenSet',
#     'FsPath',
#     'FsPathLike',
#     'FuncType',
#     'Generator',
#     'Generic',
#     'Hashable',
#     'HrTime',
#     'IO',
#     'IntStr',
#     'ItemsView',
#     'Iterable',
#     'IterableAny',
#     'IterableFloat',
#     'IterableInt',
#     'IterableNumber',
#     'IterableStr',
#     'IterableT',
#     'Iterator',
#     'JsonArrT',
#     'JsonDictT',
#     'JsonListT',
#     'JsonObjT',
#     'KT',
#     'KeyT',
#     'KeyType',
#     'KeysView',
#     'List',
#     'ListAny',
#     'ListFloat',
#     'ListInt',
#     'ListListStr',
#     'ListNumber',
#     'ListStr',
#     'ListT',
#     'Literal',
#     'Mapping',
#     'MappingView',
#     'MutableMapping',
#     'MutableSequence',
#     'MutableSet',
#     'N',
#     'NamedTuple',
#     'NewType',
#     'NoReturn',
#     'NoneBytes',
#     'NoneStr',
#     'NoneStrBytes',
#     'NoneType',
#     'Null',
#     'Number',
#     'OptFloat',
#     'OptInt',
#     'OptStr',
#     'Optional',
#     'OptionalFloat',
#     'OptionalInt',
#     'OptionalStr',
#     'Path',
#     'PathLike',
#     'Protocol',
#     'R',
#     'RT',
#     'ReturnT',
#     'ReturnType',
#     'Reversible',
#     'STDIN',
#     'STDIO',
#     'Sequence',
#     'Set',
#     'SetAny',
#     'SetFloat',
#     'SetInt',
#     'SetNumber',
#     'SetStr',
#     'SetT',
#     'ShapeType',
#     'Sized',
#     'StrBytes',
#     'StrEnum',
#     'StrIntFloat',
#     'StringEnum',
#     'SupportsAbs',
#     'SupportsBytes',
#     'SupportsComplex',
#     'SupportsFloat',
#     'SupportsInt',
#     'SupportsRound',
#     'T',
#     'TYPE_CHECKING',
#     'T_co',
#     'T_contra',
#     'Text',
#     'Tuple',
#     'TupleStrStr',
#     'TupleStrs',
#     'Txt',
#     'Type',
#     'TypeAlias',
#     'TypeVar',
#     'TypedDict',
#     'Union',
#     'VT',
#     'VT_co',
#     'V_co',
#     'ValT',
#     'ValType',
#     'ValuesView',
#     '_DT',
#     '_R',
#     '_RT',
#     '_T',
#     '__all_shed__',
#     '__all_typing__',
#     '__all_typing_extensions__',
#     '__version__',
#     'cast',
#     'final',
#     'get_type_hints',
#     'no_type_check',
#     'no_type_check_decorator',
#     'null',
#     'overload',
#     'runtime_checkable',
#     'typing',
#     'typing_extensions',
#
#     'Annotated',
#     'AsyncContextManager',
#     'AsyncGenerator',
#     'AsyncIterable',
#     'AsyncIterator',
#     'Awaitable',
#     'ChainMap',
#     'ClassVar',
#     'Concatenate',
#     'ContextManager',
#     'Coroutine',
#     'Counter',
#     'DefaultDict',
#     'Deque',
#     'Final',
#     'IntVar',
#     'Literal',
#     'NewType',
#     'NoReturn',
#     'OrderedDict',
#     'ParamSpec',
#     'ParamSpecArgs',
#     'ParamSpecKwargs',
#     'Protocol',
#     'SupportsIndex',
#     'TYPE_CHECKING',
#     'Text',
#     'Type',
#     'TypeAlias',
#     'TypeGuard',
#     'TypedDict',
#     '__all_typing_extensions__',
#     'final',
#     'get_args',
#     'get_origin',
#     'get_type_hints',
#     'overload',
#     'runtime',
#     'runtime_checkable',
#     )


__all__ = (
    'AF',
    'AbstractSet',
    'Annotated',
    'Any',
    'AnyCallable',
    'AnyFunction',
    'AnyIterable',
    'AnyIterator',
    'AnyStr',
    'ArrShape',
    'ArrayShape',
    'AsyncContextManager',
    'AsyncGenerator',
    'AsyncIterable',
    'AsyncIterator',
    'Awaitable',
    'ByteString',
    'Bytes',
    'Callable',
    'ChainMap',
    'ClassVar',
    'CmdArgsType',
    'Collection',
    'Concatenate',
    'Container',
    'ContextManager',
    'Coroutine',
    'Counter',
    'DT',
    'DefaultDict',
    'Deque',
    'Dict',
    'DictAny',
    'DictAnyAny',
    'DictFloat',
    'DictFloatFloat',
    'DictInt',
    'DictIntInt',
    'DictNumber',
    'DictNumberNumber',
    'DictStr',
    'DictStrAny',
    'DictStrInt',
    'DictStrStr',
    'El',
    'Element',
    'EnvMap',
    'EnvType',
    'F',
    'FALSE',
    'FN',
    'Final',
    'Flint',
    'FrozenSet',
    'FsPath',
    'FsPathLike',
    'FuncType',
    'Generator',
    'Generic',
    'Hashable',
    'HrTime',
    'IO',
    'IntStr',
    'IntVar',
    'ItemsView',
    'Iterable',
    'IterableAny',
    'IterableFloat',
    'IterableInt',
    'IterableNumber',
    'IterableStr',
    'IterableT',
    'Iterator',
    'JsonArrT',
    'JsonDictT',
    'JsonListT',
    'JsonObjT',
    'KT',
    'KeyT',
    'KeyType',
    'KeysView',
    'List',
    'ListAny',
    'ListFloat',
    'ListInt',
    'ListListStr',
    'ListNumber',
    'ListStr',
    'ListT',
    'Literal',
    'Mapping',
    'MappingView',
    'MutableMapping',
    'MutableSequence',
    'MutableSet',
    'N',
    'NamedTuple',
    'NewType',
    'NoReturn',
    'NoneBytes',
    'NoneStr',
    'NoneStrBytes',
    'NoneType',
    'Null',
    'Number',
    'OptFloat',
    'OptInt',
    'OptStr',
    'Optional',
    'OptionalFloat',
    'OptionalInt',
    'OptionalStr',
    'OrderedDict',
    'ParamSpec',
    'ParamSpecArgs',
    'ParamSpecKwargs',
    'Path',
    'PathLike',
    'Protocol',
    'R',
    'RT',
    'ReturnT',
    'ReturnType',
    'Reversible',
    'STDIN',
    'STDIO',
    'Sequence',
    'Set',
    'SetAny',
    'SetFloat',
    'SetInt',
    'SetNumber',
    'SetStr',
    'SetT',
    'ShapeType',
    'Sized',
    'StrBytes',
    'StrEnum',
    'StrIntFloat',
    'StringEnum',
    'SupportsAbs',
    'SupportsBytes',
    'SupportsComplex',
    'SupportsFloat',
    'SupportsIndex',
    'SupportsInt',
    'SupportsRound',
    'T',
    'TRUE',
    'TYPE_CHECKING',
    'T_co',
    'T_contra',
    'Text',
    'Tuple',
    'TupleStrStr',
    'TupleStrs',
    'Txt',
    'Type',
    'TypeAlias',
    'TypeGuard',
    'TypeVar',
    'TypedDict',
    'Union',
    'VT',
    'VT_co',
    'V_co',
    'ValT',
    'ValType',
    'ValuesView',
    '_DT',
    '_R',
    '_RT',
    '_T',
    '__all_shed__',
    '__all_typing__',
    '__all_typing_extensions__',
    '__version__',
    'cast',
    'final',
    'get_args',
    'get_origin',
    'get_type_hints',
    'no_type_check',
    'no_type_check_decorator',
    'null',
    'overload',
    'runtime',
    'runtime_checkable',
    'typing',
    'typing_extensions',
)
print(tuple(sorted(set(__all__))))



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': '.'}

packages = \
['xtyping']

package_data = \
{'': ['*']}

install_requires = \
['typing-extensions>=3.10.0,<4.0.0']

setup_kwargs = {
    'name': 'xtyping',
    'version': '0.3.0',
    'description': 'Extended typing',
    'long_description': None,
    'author': 'jesse',
    'author_email': 'jesse@dgi.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/dynamic-graphics-inc/dgpy-libs',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.1,<4.0.0',
}


setup(**setup_kwargs)



# -*- coding: utf-8 -*-
"""xtyping = typing | typing_extensions | misc"""
from enum import Enum
from os import PathLike
from pathlib import Path
from typing import (
    IO,
    Any,
    AsyncIterable,
    AsyncIterator,
    Awaitable,
    Callable,
    Dict,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
)

from typing_extensions import Literal

__all__ = (
    'AF',
    'AnyCallable',
    'AnyFunction',
    'AnyIterable',
    'AnyIterator',
    'ArrShape',
    'ArrayShape',
    'Bytes',
    'CmdArgsType',
    'DT',
    'DictAny',
    'DictAnyAny',
    'DictFloat',
    'DictFloatFloat',
    'DictInt',
    'DictIntInt',
    'DictNumber',
    'DictNumberNumber',
    'DictStr',
    'DictStrAny',
    'DictStrInt',
    'DictStrStr',
    'El',
    'Element',
    'EnvMap',
    'EnvType',
    'F',
    'FALSE',
    'FN',
    'Flint',
    'FsPath',
    'FsPathLike',
    'FuncType',
    'HrTime',
    'IO',
    'IntStr',
    'IterableAny',
    'IterableFloat',
    'IterableInt',
    'IterableNumber',
    'IterableStr',
    'IterableT',
    'JsonArrT',
    'JsonDictT',
    'JsonListT',
    'JsonObjT',
    'KT',
    'KeyT',
    'KeyType',
    'ListAny',
    'ListFloat',
    'ListInt',
    'ListListStr',
    'ListNumber',
    'ListStr',
    'ListT',
    'N',
    'NoneBytes',
    'NoneStr',
    'NoneStrBytes',
    'NoneType',
    'Null',
    'Number',
    'OptFloat',
    'OptInt',
    'OptStr',
    'OptionalFloat',
    'OptionalInt',
    'OptionalStr',
    'Path',
    'PathLike',
    'R',
    'RT',
    'ReturnT',
    'ReturnType',
    'STDIN',
    'STDIO',
    'SetAny',
    'SetFloat',
    'SetInt',
    'SetNumber',
    'SetStr',
    'SetT',
    'ShapeType',
    'StrBytes',
    'StrEnum',
    'StrIntFloat',
    'StringEnum',
    'T',
    'TRUE',
    'T_co',
    'T_contra',
    'TupleStrStr',
    'TupleStrs',
    'Txt',
    'VT',
    'VT_co',
    'V_co',
    'ValT',
    'ValType',
    '_DT',
    '_R',
    '_RT',
    '_T',
    '__all_shed__',
    'null',
)
__all_shed__ = __all__

#############
## Aliases ##
#############
Opt = Optional

###############
## LITERALLY ##
###############
TRUE = Literal[True]
FALSE = Literal[False]

##########
## NONE ##
##########
null = Null = None.__class__
NoneType = None.__class__
NoneStr = Optional[str]
NoneBytes = Optional[bytes]
StrBytes = Union[str, bytes]
NoneStrBytes = Optional[StrBytes]

############
## NUMBER ##
############
Number = Union[int, float]  # float or int
Flint = Union[int, float]  # float or int

##############
## TypeVars ##
##############
T = TypeVar('T')  # Any type.
_T = TypeVar("_T")
KT = TypeVar('KT')  # Key type.
VT = TypeVar('VT')  # Value type.
KeyT = TypeVar('KeyT')  # Key type.
ValT = TypeVar('ValT')  # Value type.
KeyType = TypeVar('KeyType')  # Key type.
ValType = TypeVar('ValType')  # Value type.
El = TypeVar("El")
Element = TypeVar("Element")
R = TypeVar("R")
RT = TypeVar("RT")
_R = TypeVar("_R")
_RT = TypeVar("_RT")
ReturnT = TypeVar("ReturnT")
ReturnType = TypeVar("ReturnType")
N = TypeVar("N", int, float)
DT = TypeVar("DT")
_DT = TypeVar("_DT")

########################
## Covariant TypeVars ##
########################
T_co = TypeVar('T_co', covariant=True)  # Any type covariant containers.
V_co = TypeVar('V_co', covariant=True)  # Any type covariant containers.
VT_co = TypeVar('VT_co', covariant=True)  # Value type covariant containers.
T_contra = TypeVar('T_contra', contravariant=True)  # Ditto contravariant.


class StringEnum(str, Enum):
    """String enum base class -- based on usage with pydantic"""

    ...


class StrEnum(StringEnum):
    """Alias for StringEnum"""

    ...


################
## Function-y ##
################
AnyCallable = Callable[..., Any]
FN = TypeVar("FN", bound=AnyCallable)
FuncType = Callable[..., Any]
F = TypeVar("F", bound=FuncType)
AF = TypeVar("AF", bound=Awaitable)

#################
## STDIO/STDIN ##
#################
STDIO = Union[None, int, bytes, IO[Any]]
STDIN = Union[bytes, str, None]

###########
## LISTS ##
###########
ListAny = List[Any]
ListT = List[T]
ListStr = List[str]
ListInt = List[int]
ListFloat = List[float]
ListNumber = List[Number]

############################
## LISTLESS AKA iterables ##
############################
IterableAny = Iterable[Any]
IterableT = Iterable[T]
IterableStr = Iterable[str]
IterableInt = Iterable[int]
IterableFloat = Iterable[float]
IterableNumber = Iterable[Number]

##########
## DICT ##
##########
DictAny = Dict[Any, Any]
DictStr = Dict[str, str]
DictInt = Dict[int, int]
DictFloat = Dict[float, float]
DictNumber = Dict[Number, Number]
DictAnyAny = Dict[Any, Any]
DictStrStr = Dict[str, str]
DictIntInt = Dict[int, int]
DictFloatFloat = Dict[float, float]
DictNumberNumber = Dict[Number, Number]
DictStrAny = Dict[str, Any]
DictStrInt = Dict[str, int]

#########
## SET ##
#########
SetAny = Set[Any]
SetT = Set[T]
SetStr = Set[str]
SetInt = Set[int]
SetFloat = Set[float]
SetNumber = Set[Number]

##########
## JSON ##
##########
# Json friendly: Union[None, bool, int, float, str, List[Any], Dict[str, Any]]
JsonDictT = Dict[str, Any]
JsonObjT = Dict[str, Any]
JsonListT = List[Any]
JsonArrT = List[Any]

##########
## MISC ##
##########
IntStr = Union[int, str]
Bytes = Union[bytes, bytearray]
Txt = Union[bytes, str]
EnvMap = Union[Mapping[bytes, Txt], Mapping[str, Txt]]
AnyIterable = Union[Iterable[T], AsyncIterable[T]]
AnyIterator = Union[Iterator[T], AsyncIterator[T]]
AnyFunction = Union[Callable[..., R], Callable[..., Awaitable[R]]]
StrIntFloat = Union[str, int, float]
HrTime = Tuple[int, int]  # node/js hrtime type annotation

###############################
## Function type annotations ##
###############################
FsPath = Union[str, Path, PathLike]
FsPathLike = PathLike
EnvType = Union[Mapping[bytes, Txt], Mapping[str, Txt]]
CmdArgsType = Union[bytes, str, Sequence[str], Sequence[FsPath]]

##############
## LISTLESS ##
##############
ArrShape = Tuple[int, ...]
ArrayShape = Tuple[int, ...]
ShapeType = Tuple[int, ...]
TupleStrs = Tuple[str, ...]
ListListStr = List[List[str]]
TupleStrStr = Tuple[str, str]

#########
## OPT ##
#########
OptionalInt = Optional[int]
OptInt = Optional[int]
OptionalStr = Optional[str]
OptStr = Optional[str]
OptionalFloat = Optional[float]
OptFloat = Optional[float]
